VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "Process"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True
'---------------------------------------------------------------------------------------
' Module    : Process
' DateTime  : 30/11/2006 17:00
' Author    : Vb System Library
' Copyright : (C) 2007 L'quipe Vb System Library
'              See "modPresentation" for more information
' Purpose   : Objet Processus
'---------------------------------------------------------------------------------------


'---------------------------------------------------------------------------------------
'
' Proprits
'       [statiques]
'   ID
'   Name
'   ParentProcessID
'   FileName
'   UserName
'   PEBAdress
'       [dynamiques]
'   Priority
'   CommandLine
'   CurrentDirectory
'   MemoryInfos
'   ProcessorTimes
'
' Mthodes
'   GetProcessByID
'   RefreshInfos
'   Kill
'   IsActive
'   GetWindows
'
'---------------------------------------------------------------------------------------

Option Explicit

Private clsProcess As New clsProcesses

' Les infos sur ce processus
Private tabInfos(0 To 10) As Variant

' Les diffrentes infos du processus
Private Enum enumProcessInfo
    eprocessID = 0                                  ' L'id
    eprocessName = 1                                ' Le nom du process : "process.exe"
    eprocessParentProcessID = 2                     ' L'id du processus parent
    eprocessFileName = 3                            ' Le nom de fichier de l'executable
    eprocessUserName = 4                            ' Le nom de l'utilisateur qui a lanc le processus
    eprocessPEBAdress = 5                           ' L'adresse de la structure PEB
    eprocessPriority = 6                            ' La priorit du processus
    eprocessCommandLine = 7                         ' Ligne de commande
    eprocessCurrentDirectory = 8                    ' Dossier courant du processus
    eprocessMemoryInfos = 9                         ' Structure d'informations sur l'utilisation mmoire
    eprocessProcessorTimes = 10                     ' Les temps processeur
End Enum



'---------------------------------------------------------------------------------------
' Les mthodes
'---------------------------------------------------------------------------------------


' Retrouve les infos statiques du processus  partir de son ID
' [Optionnel] RefreshInfos : Active ou non le rafraichissement des infos dynamiques du processus
Public Sub GetProcessByID(ByVal ProcessID As Long, Optional ByVal bRefreshInfos As Boolean = False)
    Dim P As ProcessBasicInformations
    tabInfos(eprocessID) = ProcessID
    ' Les informations statiques
    P = clsProcess.GetProcessBasicInfos(ProcessID)
    AddProcessBasicInfos P
    ' Les informations dynamiques
    If bRefreshInfos = True Then RefreshInfos
End Sub


' Rafraichit les informations dynamiques
Public Sub RefreshInfos()
    Dim ProcessID As Long
    Dim ProcTimes As ProcessorTimes
    ProcessID = tabInfos(eprocessID)
    ' Infos
    tabInfos(eprocessPriority) = clsProcess.GetProcessPriority(ProcessID)
    ' Les infos sur la mmoire
    tabInfos(eprocessMemoryInfos) = clsProcess.GetProcessMemoryInfos(ProcessID)
    ' Les temps processeur
    clsProcess.GetProcessorTimes ProcessID, ProcTimes.KernelTime, ProcTimes.UserTime, ProcTimes.ProcessorTime
    tabInfos(eprocessProcessorTimes) = ProcTimes
End Sub


' Tue le processus
Public Function Kill() As Long
    Kill = clsProcess.KillProcess(Val(tabInfos(eprocessID)))
End Function


' Renvoie TRUE si le processus est toujours actif, FALSE dans le cas contraire
Public Function IsActive() As Long
    IsActive = clsProcess.IsProcessRunning(Val(tabInfos(eprocessID)))
End Function


' Renvoie la liste des fenetres cres par le processus
Public Function GetWindows() As ListWindows
    Dim tempListWindows As ListWindows
    ' La liste des fenetres
    Set tempListWindows = New ListWindows
    tempListWindows.RefreshList , , tabInfos(eprocessID)
    Set GetWindows = tempListWindows
    Set tempListWindows = Nothing
End Function


'---------------------------------------------------------------------------------------
' Les proprits
'---------------------------------------------------------------------------------------

Public Property Get ID() As Long
    ID = tabInfos(eprocessID)
End Property
Public Property Get Name() As String
    Name = tabInfos(eprocessName)
End Property
Public Property Get ParentProcessID() As Long
    ParentProcessID = tabInfos(eprocessParentProcessID)
End Property
Public Property Get FileName() As String
    FileName = tabInfos(eprocessFileName)
End Property
Public Property Get UserName() As String
    UserName = tabInfos(eprocessUserName)
End Property
Public Property Get PEBAdress() As Long
    PEBAdress = tabInfos(eprocessPEBAdress)
End Property
Public Property Get Priority() As Long
    Priority = tabInfos(eprocessPriority)
End Property
Public Property Let Priority(ByVal lProcessPriorityLevel As Long)
    clsProcess.SetProcessPriority tabInfos(eprocessID), lProcessPriorityLevel
End Property
Public Property Get MemoryInfos() As PROCESS_MEMORY_COUNTERS
    MemoryInfos = tabInfos(eprocessMemoryInfos)
End Property
Public Property Get ProcessorTimes() As ProcessorTimes
    ProcessorTimes = tabInfos(eprocessProcessorTimes)
End Property


' Pour le rafraichissement des proprits basiques
' fonction accessible seulement depuis le projet DLL
Friend Function AddProcessBasicInfos(ProcessInfos As ProcessBasicInformations)
    tabInfos(eprocessID) = ProcessInfos.ProcessID
    tabInfos(eprocessName) = ProcessInfos.ProcessName
    tabInfos(eprocessParentProcessID) = ProcessInfos.ParentProcessID
    tabInfos(eprocessFileName) = ProcessInfos.ImageFile
    tabInfos(eprocessUserName) = ProcessInfos.UserName
    tabInfos(eprocessPEBAdress) = ProcessInfos.PEBAdress
End Function
